@@ -30,6 +30,10 @@ RE_HASH = {
 
 RE_IPV4_PADDING = re.compile(r"(^|\.)0+([^/.])")
 
+RE_BTC = re.compile(r'^(bc1|[13])[a-zA-HJ-NP-Z0-9]{25,39}$')
+
+RE_CVE = re.compile(r'^cve-[0-9]{4}-[0-9]{4,}$')
+
 
 MAP = {
     RE_IPV4: 'ipv4',
@@ -39,6 +43,8 @@ MAP = {
     RE_URI_SCHEMES: 'url',
     RE_EMAIL: 'email',
     RE_IPV4_CIDR: 'ipv4',
+    RE_BTC: 'btc',
+    RE_CVE: 'cve',
 }
 
 
@@ -53,14 +59,14 @@ Example:
     :return: indicator type string
     """
 
-    for k, v in MAP.items():
-        if k.match(i):
-            return v
-
     for k, v in RE_HASH.items():
         if v.match(i):
             return k
 
+    for k, v in MAP.items():
+        if k.match(i):
+            return v
+
 
 def main():
     import sys
